@@ -1,23 +1,29 @@
-package Net::Azure::StorageClient;
+#!perl
+# ABSTRACT: Client for Azure Blob Storage
+
 use strict;
 use warnings;
-{
-  $Net::Azure::StorageClient::VERSION = '0.5';
-}
+use v5.10;
+
+package Net::Azure::StorageClient;
+$Net::Azure::StorageClient::VERSION = '0.6';
 use LWP::UserAgent;
-use HTTP::Date;
+use HTTP::Date qw/ time2str /;
 use URI::QueryParam;
 use MIME::Base64;
 use Digest::SHA qw( hmac_sha256_base64 );
+use Digest::MD5 qw( md5_base64 );
+
+use namespace::clean;
 
 sub new {
     my $class = shift;
     my %args  = @_;
     my $type = $args{ type };
-    if ( $type && $type =~ /^Blob$/i ) { # |Table|Queue
+    if ( $type && $type =~ m/^Blob$/i ) { # |Table|Queue
         $type = ucfirst( $type );
-        $class .= "::" . $type;
-        eval "use $class;";
+        $class .= '::' . $type;
+        eval "require $class;"; ## no critic (ProhibitStringyEval)
         # die "Unsupported StorageClient $class: $@" if $@;
     }
     my $obj = bless {}, $class;
@@ -26,25 +32,22 @@ sub new {
 }
 
 sub init {
-    my $storageClient = shift;
-    my %args = @_;
-    $storageClient->{ account_name } = $args{ account_name };
-    $storageClient->{ primary_access_key } = $args{ primary_access_key };
-    $storageClient->{ api_version } = $args{ api_version } || '2012-02-12';
-    $storageClient->{ protocol } = $args{ protocol } || 'https';
-    return $storageClient;
+    my ( $self, %args ) = @_;
+    $self->{ account_name } = $args{ account_name };
+    $self->{ primary_access_key } = $args{ primary_access_key };
+    $self->{ api_version } = $args{ api_version } || '2012-02-12';
+    $self->{ protocol } = $args{ protocol } || 'https';
+    return $self;
 }
 
 sub sign {
-    my $storageClient = shift;
-    my ( $req, $params ) = @_;
-    my $key = $storageClient->{ primary_access_key };
-    my $api_version = $storageClient->{ api_version };
+    my ( $self, $req, $params ) = @_;
+    my $key = $self->{ primary_access_key };
+    my $api_version = $self->{ api_version };
     $req->header( 'x-ms-version', $api_version );
-    $req->header( 'x-ms-date', HTTP::Date::time2str() );
+    $req->header( 'x-ms-date', time2str() );
     if ( my $data = $params->{ body } ) {
-        require Digest::MD5;
-        $req->header( 'Content-MD5', Digest::MD5::md5_base64( $data ) . '==' );
+        $req->header( 'Content-MD5', md5_base64( $data ) . '==' );
         # $req->header( 'If-None-Match', '*' );
     }
     if ( $params && ( my $headers = $params->{ headers } ) ) {
@@ -55,7 +58,7 @@ sub sign {
     my $canonicalized_headers = join '', map { lc( $_ ) . ':' .
        $req->header( $_ ) . "\n" } sort grep { /^x-ms/ } keys %{ $req->headers };
     my $account = $req->uri->authority;
-    $account =~ s/^([^.]*).*$/$1/;
+    $account =~ s/^(\w+).*$/$1/;
     my $path = $req->uri->path;
     my $canonicalized_resource = "/${account}${path}";
     $canonicalized_resource .= join '', map { "\n" . lc( $_ ) . ':' .
@@ -87,17 +90,20 @@ sub sign {
     return $req;
 }
 
+# scope $ua
+{
+my $ua = LWP::UserAgent->new;
+
 sub request {
-    my $storageClient = shift;
-    my ( $method, $url, $params ) = @_;
+    my ( $self, $method, $url, $params ) = @_;
     $url = '' unless ( $url );
     if ( $url !~ m!^https{0,1}://! ) {
         if ( $url !~ m !^/! ) {
             $url = '/' . $url;
         }
-        my $type = $storageClient->{ type };
-        my $account = $storageClient->{ account_name };
-        my $protocol = $storageClient->{ protocol };
+        my $type = $self->{ type };
+        my $account = $self->{ account_name };
+        my $protocol = $self->{ protocol };
         $url = "${protocol}://${account}.${type}.core.windows.net${url}";
     }
     my $body;
@@ -105,42 +111,42 @@ sub request {
         $body = $params->{ body };
     }
     $method = 'GET' unless $method;
-    my $req = new HTTP::Request( $method => $url );
+    my $req = HTTP::Request->new( $method => $url );
     $req->content_length( length( $body ) ) if defined $body;
-    $req = $storageClient->sign( $req, $params );
+    $req = $self->sign( $req, $params );
     $req->content( $body ) if defined $body;
-    my $ua = LWP::UserAgent->new;
     return $ua->request( $req );
 }
 
+} # scope $ua
+
 sub get {
-    my $storageClient = shift;
-    $storageClient->request( 'GET', @_ );
+    my $self = shift;
+    $self->request( 'GET', @_ );
 }
 
 sub head {
-    my $storageClient = shift;
-    $storageClient->request( 'HEAD', @_ );
+    my $self = shift;
+    $self->request( 'HEAD', @_ );
 }
 
 sub put {
-    my $storageClient = shift;
-    $storageClient->request( 'PUT', @_ );
+    my $self = shift;
+    $self->request( 'PUT', @_ );
 }
 
 sub delete {
-    my $storageClient = shift;
-    $storageClient->request( 'DELETE', @_ );
+    my $self = shift;
+    $self->request( 'DELETE', @_ );
 }
 
 sub post {
-    my $storageClient = shift;
-    $storageClient->request( 'POST', @_ );
+    my $self = shift;
+    $self->request( 'POST', @_ );
 }
 
 sub _signed_identifier {
-    my $storageClient = shift;
-    my $length = shift;
+    my ( $self, $length ) = @_;
     my @char = () ;
     push @char, ( 'a' .. 'z' );
     push @char, ( 'A' .. 'Z' );
@@ -153,16 +159,15 @@ sub _signed_identifier {
 }
 
 sub _adjust_path {
-    my $storageClient = shift;
-    my $path = shift;
+    my ( $self, $path ) = @_;
     $path =~ s!^/!!;
-    if ( my $type = $storageClient->{ type } ) {
+    if ( my $type = $self->{ type } ) {
         my $arg;
         if ( $type eq 'blob' ) {
             $arg = 'container_name'
         }
         # table, queue...
-        if ( $arg && ( my $root = $storageClient->{ $arg } ) ) {
+        if ( $arg && ( my $root = $self->{ $arg } ) ) {
             $path = $root . '/' . $path;
         }
     }
@@ -173,9 +178,17 @@ sub _adjust_path {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Net::Azure::StorageClient - Windows Azure Storage Client
+Net::Azure::StorageClient - Client for Azure Blob Storage
+
+=head1 VERSION
+
+version 0.6
 
 =head1 SYNOPSIS
 
@@ -186,6 +199,10 @@ Net::Azure::StorageClient - Windows Azure Storage Client
                                     [ protocol => 'https', ]
                                     [ api_version => '2012-02-12', ] );
 
+=head1 NAME
+
+Net::Azure::StorageClient - Windows Azure Storage Client
+
 =head1 METHODS
 
 =head2 sign
@@ -193,7 +210,7 @@ Net::Azure::StorageClient - Windows Azure Storage Client
 Specifying the authorization header to HTTP::Request object.
 http://msdn.microsoft.com/en-us/library/dd179428.aspx
 
-    my $req = new HTTP::Request( 'GET', $url );
+    my $req = HTTP::Request->new( 'GET', $url );
     $req = $StorageClient->sign( $req, $params );
 
 =head2 request
@@ -210,7 +227,7 @@ Specifying the authorization header and send request.
     my $res = $StorageClient->request( 'GET', $url );
 
     # Request with custom http headers and request body. Send POST request.
-    my $params = { 
+    my $params = {
                    headers => { 'x-ms-foo' => 'bar', },
                    body => $request_body,
                  };
@@ -242,13 +259,35 @@ Specifying the authorization header and send 'POST' request.
 
 Junnama Noda <junnama@alfasado.jp>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2013, Junnama Noda.
+This software is copyright (c) 2020 by Junnama Noda.
 
-=head1 LICENSE
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
-This program is free software;
-you can redistribute it and modify it under the same terms as Perl itself.
+=head1 CONTRIBUTORS
 
-=cut
\ No newline at end of file
+=for stopwords Alexandr Ciornii Dean Hamstead ksasakims paulbort
+
+=over 4
+
+=item *
+
+Alexandr Ciornii <alexchorny@gmail.com>
+
+=item *
+
+Dean Hamstead <djzort@cpan.org>
+
+=item *
+
+ksasakims <gitsasa@outlook.com>
+
+=item *
+
+paulbort <paulbort@gmail.com>
+
+=back
+
+=cut
